from setuptools import setup

setup(
  name='ordr',
  version='0.0.1',
  author='Francesco Boffa',
  author_email='francesco@ordr.menu',
  packages=['ordr'],
  url='https://ordr.menu',
  license='MIT',
  description='Python SDK for the ORDR API',
  install_requires=[
      "pytest"
  ],
)
